from datetime import datetime

from dotenv import load_dotenv
from peewee import *
from playhouse.sqliteq import SqliteQueueDatabase


load_dotenv('.env')

db = SqliteQueueDatabase('data/mm.db')


class Ticker(Model):
    id = AutoField()
    trade_pair = CharField()
    initial_price = DoubleField()
    current_price = DoubleField()
    high_price = DoubleField()
    low_price = DoubleField()
    volume = DoubleField()
    bid = DoubleField()
    ask = DoubleField()
    spread_btc = DoubleField()
    spread_sats = IntegerField()
    spread_perc = DoubleField()
    date = DateTimeField(default=datetime.utcnow)

    class Meta:
        database = db

class Balance(Model):
    total = DoubleField()
    available = DoubleField()
    currency = CharField()
    date = DateTimeField(default=datetime.utcnow)

    class Meta:
        database = db

class Order(Model):
    trade_pair = CharField()
    trade_type = CharField()
    buy = BooleanField()
    quantity = DoubleField()
    price = DoubleField()
    uuid = TextField(null=True)
    active = BooleanField(default=True)
    cancelled = BooleanField(default=False)
    date = DateTimeField(default=datetime.utcnow)

    class Meta:
        database = db

class Trade(Model):
    trade_pair = CharField()
    trade_type = CharField()
    buy = BooleanField()
    quantity = DoubleField()
    price = DoubleField()
    date = DateTimeField()

    class Meta:
        database = db

class BitcoinPrice(Model):
    price = DoubleField()
    date = DateTimeField(default=datetime.utcnow)

    class Meta:
        database = db

class Earning(Model):
    trade_pair = CharField()
    quantity = DoubleField()
    date = DateTimeField(default=datetime.utcnow)

    class Meta:
        database = db

db.create_tables([Ticker, Balance, Order, Earning, Trade, BitcoinPrice])
